@@ -236,7 +236,7 @@ int dict_add_true_size(DICT *dict, int n)
 //des zros
 void dict_init(DICT *list)
 {
-		memset(list,0,sizeof(DICT));
+	memset(list,0,sizeof(DICT));
 }
 
 //pour ajouter un thme  la liste des themes
@@ -355,8 +355,11 @@ char *dict_get_description(int index) //la description de quel mot?
 
 		//initialise la description complte (celle qu'on va retourner)
 		//ajout du mot dans la description
+		char *mot = gs_replace_m(dict.entry[index].word,"<","&lt;"); if(!mot) return 0;
+		mot = gs_replace_r(mot,">","&gt;"); if(!mot) return 0;
+
 		description=strdup("<i>");
-		description=gs_strcat_r(description,dict.entry[index].word);
+		description=gs_strcat_r(description,mot); /* ajout et */ free(mot); /* dsallocation */
 		description=gs_strcat_r(description,"</i><p>");
 		if(!description) return 0;
 
